@@ -431,7 +431,7 @@ def raw_Gamma_diss(T: float, T1: float, vibr_one: float, Z_int: float, mass_mole
     T1 : float
         the temperature of the first vibrational level of the molecule M
     vibr_one : float
-        the dimensional energy of the first vibrational level of the molecule which dissociates
+        the dimensional energy of the first vibrational level of the molecule which dissociates (with offset)
     Z_int : float
         the value of the internal partition function of the molecule which dissociates
     mass_molecule : float
@@ -441,7 +441,7 @@ def raw_Gamma_diss(T: float, T1: float, vibr_one: float, Z_int: float, mass_mole
     mass_atom2 : float
         the mass of the second atom product of dissociation
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with offset)
     n_molecule : float
         the numeric density of molecules of species M
     n_atom1 : float
@@ -449,8 +449,7 @@ def raw_Gamma_diss(T: float, T1: float, vibr_one: float, Z_int: float, mass_mole
     n_atom2 : float
         the numeric density of atoms of species atom2
     diss_level : int
-        the vibrational level from which the molecule dissociates (for a one-temperature aprroximation,
-        where T=T1, this parameter plays no role and can be chosen arbitrarily)
+        the vibrational level from which the molecule dissociates
 
     Returns
     -------
@@ -484,7 +483,7 @@ def raw_Gamma_diss_oneT(T: float, Z_int: float, mass_molecule: float, mass_atom1
     mass_atom2 : float
         the mass of the second atom product of dissociation
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     n_molecule : float
         the numeric density of molecules of species M
     n_atom1 : float
@@ -521,7 +520,7 @@ def raw_find_natom_diss_eq(T: float, Z_int: float, mass_molecule: float, mass_at
     mass_atom : float
         the mass of the atomic species which make up the molecule
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     n : float
         the total numeric density of the mixture
     relative : bool, optional
@@ -543,8 +542,8 @@ def raw_find_natom_diss_eq(T: float, Z_int: float, mass_molecule: float, mass_at
 
 def Gamma_diss_binary_equilibrium_xatom(x_atom: float, Z_int: float, mass_molecule: float, mass_atom: float,
                                         molecule_diss: float, T: float, n: float) -> float:
-    """A helper function, which calculates Gamma_diss (multiplied by the numeric density of the molecules) for a binary
-    mixture (A2, A) in vibrational equilibrium (a one-temperature distribution is used): **2A + A -> 3A**
+    """A helper function, which calculates Gamma_diss (multiplied by the relative numeric density of the molecules)
+    for a binary mixture (A2, A) in vibrational equilibrium (a one-temperature distribution is used): **2A + A -> 3A**
 
     Parameters
     ----------
@@ -559,7 +558,7 @@ def Gamma_diss_binary_equilibrium_xatom(x_atom: float, Z_int: float, mass_molecu
     mass_atom : float
         the mass of the atomic species which make up the molecule
     molecule_diss : float
-        the dissociation energy of the molecule which dissociates
+        the dissociation energy of the molecule which dissociates (with no offset)
     n : float
         the total numeric density of the mixture
 
@@ -568,9 +567,8 @@ def Gamma_diss_binary_equilibrium_xatom(x_atom: float, Z_int: float, mass_molecu
     float
         Gamma_diss multiplied by the numeric density of the molecules
     """
-    n_atom = x_atom * n
-    mult = Z_int * (n_atom ** 2) * (constants.h ** 3)\
-                                 * ((mass_molecule / (2.0 * mass_atom * mass_atom * constants.pi
+    mult = Z_int * n * (x_atom ** 2) * (constants.h ** 3)\
+                                     * ((mass_molecule / (2.0 * mass_atom * mass_atom * constants.pi
                                                                * constants.k * T)) ** 1.5)\
-                                 * exp(molecule_diss / (constants.k * T))
-    return (n - n_atom) - mult
\ No newline at end of file
+                                     * exp(molecule_diss / (constants.k * T))
+    return 1.0 - x_atom - mult
\ No newline at end of file
