@@ -670,10 +670,10 @@ def raw_crosssection_vt_fho(g: float, T: float, sigma: float, mass: float, beta:
         The VT crosssection
     """
     if rig_sphere:
-        return prob.vt_probability(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
+        return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
                * raw_crosssection_rigid_sphere(sigma)
     else:
-        return prob.vt_probability(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
+        return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
                * raw_crosssection_VSS(g, T, vssc, vsso)
 
 
@@ -720,10 +720,10 @@ def raw_crosssection_vv_fho(g, T: float, sigma: float, mass: float, beta: float,
         The VV crosssection
     """
     if rig_sphere:
-        return prob.vv_probability(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
+        return prob.vv_probability_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
                * raw_crosssection_rigid_sphere(sigma)
     else:
-        return prob.vv_probability(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
+        return prob.vv_probability_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2, i, k, i_delta)\
                * raw_crosssection_VSS(g, T, vssc, vsso)
 
 
@@ -896,7 +896,7 @@ def raw_vt_integral_fho(T: float, deg: int, mass: float, beta: float, vssc: floa
     """
     if delta != 0:
         molecule_depth = molecule_vibr_zero + molecule_diss
-        f = lambda g: prob.vt_prob_g_only(g, T, mass, beta, ve_before, ve_after,
+        f = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
                                           i, delta, molecule_depth)\
                       * elastic_omega_g_only_vss(g, deg, vsso)
         if delta == 1:
@@ -960,7 +960,7 @@ def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: flo
     """
     if delta != 0:
         molecule_depth = molecule_vibr_zero + molecule_diss
-        f = lambda g: prob.vt_prob_g_only(g, T, mass, beta, ve_before, ve_after,
+        f = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
                                           i, delta, molecule_depth)\
                       * elastic_omega_g_only_rigid_sphere(g, deg)
         if delta == 1:
@@ -1028,7 +1028,7 @@ def raw_vv_integral_fho(T: float, deg: int, mass: float, beta: float, vssc: floa
         if ``i_delta == 0``
     """
     if i_delta != 0:
-        f = lambda g: prob.vv_prob_g_only(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2,
+        f = lambda g: prob.vv_prob_g_only_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2,
                                           i, k, i_delta) * elastic_omega_g_only_vss(g, deg, vsso)
         if i_delta == 1:
             mult = (i + 1) * k
@@ -1097,7 +1097,7 @@ def raw_vv_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: flo
         if ``i_delta == 0``
     """
     if i_delta != 0:
-        f = lambda g: prob.vv_prob_g_only(g, T, mass, beta, ve_before1, ve_after1, ve_before2,
+        f = lambda g: prob.vv_prob_g_only_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2,
                                           ve_after2, i, k, i_delta) * elastic_omega_g_only_rigid_sphere(g, deg)
         if i_delta == 1:
             mult = (i + 1) * k
