@@ -156,10 +156,6 @@ class Molecule(Particle):
         The anharmonic coefficient in the formula for vibrational level energies
     diss : float
         The dissociation energy of the molecule
-    diss_offset : float
-        This is equal to the dissociation energy of the molecule for Molecule and MoleculeOneT instance,
-        for MoleculeMultiT instances this is equal to the dissociation energy of the molecule offset
-        by the energy of the 0-th vibrational level
     rot : ndarray
         The array of rotational energies for each level
     vibr : ndarray
@@ -207,7 +203,6 @@ class Molecule(Particle):
         self.hvc = raw_d[6] * 100 * constants.h * constants.c
         self.avc = raw_d[7]
         self.diss = raw_d[8] * constants.physical_constants['electron volt'][0]
-        self.diss_offset = self.diss
         form = raw_d[9] * constants.physical_constants['electron volt'][0]
         LJe = raw_d[10]  # stored as eps/kboltz
         LJs = raw_d[11] * constants.physical_constants['Angstrom star'][0]
@@ -424,7 +419,7 @@ class Molecule(Particle):
             if dimensional:
                 return self._current_raesq
             else:
-                return self._current_raesq / self._current_kT
+                return self._current_raesq / (self._current_kT ** 2)
 
     def Z_vibr_eq(self, T: float, model: str='none') -> float:
         """Returns the equilibrium vibrational partition function :math:`Z_{eq}(T)` (which is used in various
@@ -530,9 +525,7 @@ class MoleculeQuasi(Molecule):
         self._current_edt = 0.0
         self._current_zdt = 0.0
         self._current_vae = 0.0
-        self._current_vae_dimensionless = 0.0
         self._current_vaesq = 0.0
-        self._current_vaesq_dimensionless = 0.0
         self._current_edt = 0.0
 
         self._current_kT = 0.0
@@ -588,13 +581,9 @@ class MoleculeMultiT(MoleculeQuasi):
         self._current_zdt = 0.0
         self._current_zdt1 = 0.0
         self._current_vae = 0.0
-        self._current_vae_dimensionless = 0.0
         self._current_vaesq = 0.0
-        self._current_vaesq_dimensionless = 0.0
         self._current_vae_i = 0.0
-        self._current_vae_i_dimensionless = 0.0
         self.vibr -= self.vibr_zero
-        self.diss_offset -= self.vibr_zero
 
     def renorm(self, T: float, T1: float, n_c: float):
         """Calculates all _current values for the molecule
@@ -616,10 +605,8 @@ class MoleculeMultiT(MoleculeQuasi):
 
         self._current_Z_vibr = self.Z_vibr(T, T1)
         self._current_Z_int = self.Z_int(T, T1)
-        self._current_vae_dimensionless = self.avg_vibr_energy(T, T1, False)
         self._current_vae = self.avg_vibr_energy(T, T1, True)
         self._current_vaesq = self.avg_vibr_energy_sq(T, T1, True)
-        self._current_vaesq_dimensionless = self.avg_vibr_energy_sq(T, T1, False)
         self._current_avg_i = self.avg_i(T, T1)
         self._current_avg_i_sq = self.avg_i_sq(T, T1)
         self._current_wdt = self.W_dT(T, T1)
@@ -629,7 +616,6 @@ class MoleculeMultiT(MoleculeQuasi):
         self._current_zdt = self.Z_vibr_dT(T, T1)
         self._current_zdt1 = self.Z_vibr_dT1(T, T1)
         self._current_vae_i = self.avg_vibr_energy_i(T, T1, True)
-        self._current_vae_i_dimensionless = self.avg_vibr_energy_i(T, T1, False)
 
         a = np.arange(0, self.num_vibr + 1, 1)
         self._current_v_exp = self.vibr_exp(T, T1, a)
@@ -768,7 +754,7 @@ class MoleculeMultiT(MoleculeQuasi):
             if dimensional:
                 return self._current_vae
             else:
-                return self._current_vae_dimensionless
+                return self._current_vae / self._current_kT
 
     def avg_full_energy(self, T: float, T1: float, dimensional: bool=True) -> float:
         """Returns the full internal energy averaged over the internal spectrum (either dimensional
@@ -823,7 +809,7 @@ class MoleculeMultiT(MoleculeQuasi):
             if dimensional:
                 return self._current_vaesq
             else:
-                return self._current_vaesq_dimensionless
+                return self._current_vaesq / (self._current_kT ** 2)
 
     def avg_i(self, T: float, T1: float) -> float:
         """Returns the average amount of vibrational quanta :math:`<i>_{vibr}`
@@ -901,7 +887,7 @@ class MoleculeMultiT(MoleculeQuasi):
             if dimensional:
                 return self._current_vae_i
             else:
-                return self._current_vae_i_dimensionless
+                return self._current_vae_i / self._current_kT
 
     def ni(self, T: float, T1: float, i, n_c: float) -> float:
         """Returns the numeric density of the ``i``-th vibrational level :math:`n_{i}` for the molecular species
@@ -1288,12 +1274,6 @@ class MoleculeOneT(MoleculeQuasi):
             else:
                 return np.dot(self.vibr_exp(T, a), np.power(self.vibr[a]
                                                                   / (constants.k * T), 2)) / self.Z_vibr(T)
-            # else:
-            #     if dimensional:
-            #         return np.dot(self.vibr_exp(T, a, False), np.power(self.vibr[a], 2)) / self.Z_vibr(T, False)
-            #     else:
-            #         return np.dot(self.vibr_exp(T, a, False), np.power(self.vibr[a]
-            #                       / (constants.k * T), 2)) / self.Z_vibr(T, False)
         else:
             if dimensional:
                 return self._current_vaesq
