@@ -108,8 +108,8 @@ def vel_avg_vv(g: float, ve_before1: float, ve_after1: float, ve_before2: float,
         return 0.5 * (g + (gn_sq ** 0.5))
 
 
-def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float,
-                   molecule_vibr_zero: float, molecule_diss: float, i: int, delta: int) -> float:
+def vt_probability_fho(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float,
+                       molecule_vibr_zero: float, molecule_diss: float, i: int, delta: int) -> float:
     """Returns the probability of a VT transition using the FHO (Forced harmonic oscillator) model
     **M(i) + P -> M(i + delta) + P**
 
@@ -165,8 +165,8 @@ def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: floa
     return ns * (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
 
 
-def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int, delta: int,
-                   depth: float) -> float:
+def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int,
+                       delta: int, depth: float) -> float:
     """Returns the velocity-dependent part of the probability of a VT transition using
     the FHO (Forced harmonic oscillator) model **M(i) + P -> M(i + delta) + P**
 
@@ -238,8 +238,8 @@ def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: floa
         return (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
 
 
-def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
-                   ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
+def vv_probability_fho(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
+                       ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
     """Returns the probability of a VV transition using the FHO (Forced harmonic oscillator) model
     **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
 
@@ -304,8 +304,8 @@ def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: flo
     return rhoxi * ns1 * ns2 * exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
 
 
-def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
-                   ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
+def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
+                       ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
     """Returns the velocity-dependent part of the probability of a VV transition using the FHO
     (Forced harmonic oscillator) model **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
 
