@@ -322,15 +322,15 @@ def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecu
             res += raw_rec_rate_treanor_marrone_sts(T, model_data[0], model_data[1],
                                                     molecule.Z_diss(T, i, model), molecule.Z_rot(T), molecule.mass,
                                                     atom1.mass, atom2.mass, molecule.vibr[i] + molecule.vibr_zero,
-                                                    molecule.diss) * molecule.vibr_exp(T, T1, i)
-        return res / molecule.Z_vibr(T, T1)
+                                                    molecule.diss)
+        return res
     else:
         for i in range(molecule.num_vibr + 1):
             res += raw_rec_rate_treanor_marrone_sts(T, model_data[0], model_data[1],
                                                     molecule.Z_diss(T, i, model), molecule.Z_rot(T), molecule.mass,
                                                     atom1.mass, atom2.mass, molecule.vibr[i],
-                                                    molecule.diss) * molecule.vibr_exp(T, i)
-        return res / molecule.Z_vibr(T)
+                                                    molecule.diss)
+        return res
 
 
 def rec_rate_rigid_sphere(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom,
@@ -549,41 +549,4 @@ def raw_rec_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, Z_rot: fl
     return Z_rot * (constants.h ** 3) * ((mass_molecule / (2.0 * mass_atom1
                                                            * mass_atom2 * constants.pi * constants.k * T)) ** 1.5)\
            * exp(-(molecule_diss - molecule_vibr) / (constants.k * T))\
-           * raw_diss_rate_rigid_sphere_sts(T, sigma, mass, molecule_vibr, molecule_diss, center_of_mass, vl_dependent)
-
-
-def raw_rec_rate_treanor_marrone(T: float, arrhenius_n: float, arrhenius_A: float,
-                                 Z_int: float, mass_molecule: float, mass_atom1: float,
-                                 mass_atom2: float, molecule_diss: float) -> float:
-    """Calculates the averaged recombination rate constant using the Treanor-Marrone
-    model, *raw* version
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    arrhenius_n : float
-        Arrhenius model n parameter
-    arrhenius_A : float
-        Arrhenius model A parameter
-    Z_int : float
-        the value of the internal partition function of the molecule which dissociates
-    mass_molecule : float
-        the mass of the molecule which dissociates
-    mass_atom1 : float
-        the mass of the first atom product of dissociation
-    mass_atom2 : float
-        the mass of the second atom product of dissociation
-    molecule_diss : float
-        the dissociation energy of the molecule which dissociates (with no offset)
-
-    Returns
-    -------
-    float
-        Averaged recombination rate constant
-
-    """
-    return Z_int * (constants.h ** 3) * ((mass_molecule / (2.0 * mass_atom1
-                                                           * mass_atom2 * constants.pi * constants.k * T)) ** 1.5)\
-           * exp(-molecule_diss / (constants.k * T))\
-           * raw_k_diss_eq(T, arrhenius_n, arrhenius_A, molecule_diss)
\ No newline at end of file
+           * raw_diss_rate_rigid_sphere_sts(T, sigma, mass, molecule_vibr, molecule_diss, center_of_mass, vl_dependent)
\ No newline at end of file
