@@ -15,7 +15,7 @@ import numpy as np
 
 
 def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infcoll: float,
-                 model: str='ESA') -> float:
+                 model: str='ESA', Zr_model: str='VSS') -> float:
     """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral
 
     Parameters
@@ -41,13 +41,22 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infc
             * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
 
         defaults to 'ESA'
+    Zr_model : str
+        the model used to calculate the collision amount needed to reach rotational equilibrium, possible values:
+            * 'VSS' (Variable Soft Sphere model)
+            * 'VHS' (Variable Hard Sphere model)
+            * the rigid sphere model will be used otherwise
+
+        defaults to 'VSS'
 
     Returns
     -------
     float
         Rotational relaxation time
     """
-    return raw_rot_rel_time(T, omega(T, 2, 2, idata, model=model, nokt=False), molecule.LJe, n, infcoll)
+    return raw_rot_rel_time(T, omega(T, 2, 2, idata, model=model, nokt=False), n,
+                            raw_Zr(T, idata[0], molecule.LJe, idata[6], idata[11], idata[12], molecule.mass, infcoll,
+                                   Zr_model))
 
 
 def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: Particle, n: float,
@@ -121,26 +130,6 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
                                 molecule.mass, n, infcoll, model)
 
 
-def Zr_original(T: float, molecule: Molecule, infcoll: float) -> float:
-    """Calculates the collision amount needed to reach rotational equilibrium for the rigid sphere model
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    molecule : Molecule or any subclass (MoleculeMultiT, MoleculeOneT)
-        the molecule for which the collision amount is being calculated
-    infcoll : float
-        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
-
-    Returns
-    -------
-    float
-        Amount of collisions needed to reach rotational equilibrium
-    """
-    return raw_Zr_original(T, molecule.LJe, infcoll)
-
-
 def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: str='VSS') -> float:
     """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models
 
@@ -192,7 +181,7 @@ def millikan_white(T: float, idata: np.ndarray, molecule: Molecule, p: float) ->
     return raw_millikan_white(T, idata[0], molecule.hvc, p)
 
 
-def raw_rot_rel_time(T: float, omega_integral: float, eps: float, n: float, infcoll: float) -> float:
+def raw_rot_rel_time(T: float, omega_integral: float, n: float, Zr) -> float:
     """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral,
     *raw* version
 
@@ -202,19 +191,17 @@ def raw_rot_rel_time(T: float, omega_integral: float, eps: float, n: float, infc
         the temperature of the mixture
     omega_integral : float
         the value of the dimensional :math:`\\Omega^{(2,2)}` integral to be used in the calculation
-    eps : float
-        the Lennard-Jones :math:`\\varepsilon_{cd}` parameter of the molecule, divided by Boltzmann's constant
     n : float
         the numeric density of the mixture
-    infcoll : float
-        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
+    Zr : float
+        the amount of collisions required to reach rotational equilibrium
 
     Returns
     -------
     float
         Rotational relaxation time
     """
-    return 0.15625 * (constants.pi ** 2) * raw_Zr_original(T, eps, infcoll) / (n * omega_integral)  # 0.15625 is 5 / 32
+    return 0.15625 * (constants.pi ** 2) * Zr / (n * omega_integral)  # 0.15625 is 5 / 32
 
 
 def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
@@ -376,29 +363,6 @@ def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: floa
                                      * (constants.physical_constants['Angstrom star'][0] ** 2))
 
 
-def raw_Zr_original(T: float, eps: float, infcoll: float) -> float:
-    """Calculates the collision amount needed to reach rotational equilibrium for the hard sphere model, *raw* version
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    eps : float
-        the Lennard-Jones :math:`\\varepsilon_{cd}` parameter of the molecule, divided by Boltzmann's constant
-    infcoll : float
-        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
-
-    Returns
-    -------
-    float
-        Amount of collisions needed to reach rotational equilibrium
-    """
-    TTstar = eps / T
-    F = 1 + 0.5 * (constants.pi ** 1.5) * (TTstar ** 0.5)\
-        + (0.25 * (constants.pi ** 2) + 2) * TTstar + (constants.pi ** 1.5) * (TTstar ** 1.5)
-    return infcoll / F
-
-
 def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflection: float, vsso_deflection: float,
            mass: float, infcoll: float, model: str='VSS') -> float:
     """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models,
